@@ -9,7 +9,7 @@ use File::Spec();
 
 my $SEP = File::Spec->catfile('', '');
 
-our $VERSION = '0.000016';
+our $VERSION = '0.000017';
 
 # Directly modifying this is a bad idea, but for the XS to work it needs to be
 # a package var, not a lexical.
@@ -499,17 +499,27 @@ This should be set to a module that implements the following method:
 
     sub test_parameters {
         my $class = shift;
-        my ($test_file, @from_values) = @_;
+        my ($test_file, \@from_values) = @_;
 
         ...
 
-        # Any or all of these may be undef or omitted, can also return 'undef'
-        # instead of a hashref if no parameters are needed.
         return {
+            # If true - run the test
+            # If false - skip the test
+            # If not present or undef - run the test
+            run => $bool,
+
+            # The following are optional
             argv  => [ ... ],
             env   => { ... },
             stdin => "...",
         };
+
+        # OR
+        # If true - run the test
+        # If false - skip the test
+        # If undef or empty list - run the test
+        return $bool;
     }
 
 This will be used by L<Test2::Harness> to determine what data needs to be
